==> hledger-iadd-1.3.20-25-riscv64.pkg.tar.zst: usr/share/haskell/register/hledger-iadd.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hledger-iadd
version:              1.3.20
visibility:           public
id:                   hledger-iadd-1.3.20-1nzUDfwTBqxFFftWeLJoD5
key:                  hledger-iadd-1.3.20-1nzUDfwTBqxFFftWeLJoD5
license:              BSD-3-Clause
copyright:            2018 Hans-Peter Deifel
maintainer:           Hans-Peter Deifel <hpd@hpdeifel.de>
author:               Hans-Peter Deifel <hpd@hpdeifel.de>
homepage:             https://github.com/hpdeifel/hledger-iadd#readme
synopsis:             A terminal UI as drop-in replacement for hledger add
description:
    This is a terminal UI as drop-in replacement for hledger add.

    It improves in the following ways on hledger'\''s add command:

    * Interactive as-you-type completion for
    account names and descriptions with optional
    fuzzy matching.

    * Integrated calculator: Amounts can be written
    as simple sums with real-time feedback on the
    result.

    * All actions while entering a transaction can
    be undone

    * Configurable format for date input. Instead
    of @y\/m\/d@ it is also possible to use other
    formats like the german @d.m.y@.

category:             Finance, Console
abi:                  2d683b8278f81e304acf0aac4b50cd93
exposed:              True
exposed-modules:
    AmountParser Brick.Widgets.BetterDialog Brick.Widgets.Border.Utils
    Brick.Widgets.CommentDialog Brick.Widgets.Edit.EmacsBindings
    Brick.Widgets.HelpMessage Brick.Widgets.List.Utils
    Brick.Widgets.WrappedText ConfigParser Data.Time.Ext DateParser
    Model View

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hledger-iadd-1.3.20
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hledger-iadd-1.3.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger-iadd
hs-libraries:         HShledger-iadd-1.3.20-1nzUDfwTBqxFFftWeLJoD5
depends:
    base-4.16.4.0 brick-1.7-B4Yq1iITPqI3EctG6nlIAw containers-0.6.5.1
    directory-1.3.6.2 free-5.1.10-FyWFx6eRyNxArr5kR2KlpL
    hledger-lib-1.32.1-4SFknH02xqo7HhqGxvLdLW
    megaparsec-9.5.0-Bj42S1sxqz5CEZGEYlrAL4
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    microlens-mtl-0.2.0.3-K2j2D46quth4CyQpetHsMp
    microlens-th-0.4.3.14-N8oH2Lt1wGBzxrEjsZjaw
    optparse-applicative-0.17.1.0-EVzrhDWWxX13a7yQJqV4uv text-1.2.5.0
    text-zipper-0.13-HhM6ihYHRie9D4lgb5mrCW time-1.11.1.1
    transformers-0.5.6.2
    unordered-containers-0.2.20-Kaqz4YtssULDpEsD0of7Qa
    vector-0.13.1.0-HyaXkpW7aOFHhHqdwTfvZq
    vty-5.38-6iNHPUSq77f7n6zBUIyJpV
    xdg-basedir-0.2.2-BAENMrhgj9o4xkjbLJyx83

haddock-interfaces:   /usr/share/doc/hledger-iadd/html/hledger-iadd.haddock
haddock-html:         /usr/share/doc/hledger-iadd/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hledger-iadd-1.3.20-46-riscv64.pkg.tar.zst: usr/share/haskell/register/hledger-iadd.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hledger-iadd
version:              1.3.20
visibility:           public
id:                   hledger-iadd-1.3.20-KB2dlQvSGLHLc37hDSXNgZ
key:                  hledger-iadd-1.3.20-KB2dlQvSGLHLc37hDSXNgZ
license:              BSD-3-Clause
copyright:            2018 Hans-Peter Deifel
maintainer:           Hans-Peter Deifel <hpd@hpdeifel.de>
author:               Hans-Peter Deifel <hpd@hpdeifel.de>
homepage:             https://github.com/hpdeifel/hledger-iadd#readme
synopsis:             A terminal UI as drop-in replacement for hledger add
description:
    This is a terminal UI as drop-in replacement for hledger add.

    It improves in the following ways on hledger'\''s add command:

    * Interactive as-you-type completion for
    account names and descriptions with optional
    fuzzy matching.

    * Integrated calculator: Amounts can be written
    as simple sums with real-time feedback on the
    result.

    * All actions while entering a transaction can
    be undone

    * Configurable format for date input. Instead
    of @y\/m\/d@ it is also possible to use other
    formats like the german @d.m.y@.

category:             Finance, Console
abi:                  6a278e6ebbfa9c9eac8c66ae1bc7656b
exposed:              True
exposed-modules:
    AmountParser Brick.Widgets.BetterDialog Brick.Widgets.Border.Utils
    Brick.Widgets.CommentDialog Brick.Widgets.Edit.EmacsBindings
    Brick.Widgets.HelpMessage Brick.Widgets.List.Utils
    Brick.Widgets.WrappedText ConfigParser Data.Time.Ext DateParser
    Model View

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hledger-iadd-1.3.20
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hledger-iadd-1.3.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger-iadd
hs-libraries:         HShledger-iadd-1.3.20-KB2dlQvSGLHLc37hDSXNgZ
depends:
    base-4.16.4.0 brick-1.7-4OkUY7YVpQ5GIBLUvkvTqY containers-0.6.5.1
    directory-1.3.6.2 free-5.1.10-GOblXT8Z2deK2DPOVW8Wt0
    hledger-lib-1.32.1-93So1L5wGd9EWwe4MbIKLM
    megaparsec-9.6.0-6jYDQ0q8YWM1z9BbCkR7uD
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    microlens-mtl-0.2.0.3-K2j2D46quth4CyQpetHsMp
    microlens-th-0.4.3.15-BttKu46tg2TPgxEFeI4m6
    optparse-applicative-0.17.1.0-AgMeQrX7nmlDOnX2xcegDb text-1.2.5.0
    text-zipper-0.13-AkbMvTcVP7HDKQYpH6Eucd time-1.11.1.1
    transformers-0.5.6.2
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r
    vty-5.38-CaRMGIrplVnJIAnXF6jMgR
    xdg-basedir-0.2.2-BAENMrhgj9o4xkjbLJyx83

haddock-interfaces:   /usr/share/doc/hledger-iadd/html/hledger-iadd.haddock
haddock-html:         /usr/share/doc/hledger-iadd/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
